@@ -91,6 +91,7 @@ EXTENSIONS = {
     'kt': {'text', 'kotlin'},
     'less': {'text', 'less'},
     'lhs': {'text', 'literate-haskell'},
+    'libsonnet': {'text', 'jsonnet'},
     'lidr': {'text', 'idris'},
     'lua': {'text', 'lua'},
     'm': {'text', 'c', 'objective-c'},
@@ -141,6 +142,7 @@ EXTENSIONS = {
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
     's': {'text', 'asm'},
+    'sass': {'text', 'sass'},
     'sbt': {'text', 'sbt', 'scala'},
     'sc': {'text', 'scala'},
     'scala': {'text', 'scala'},
